@@ -10,7 +10,7 @@ use MooX::Press::Keywords ();
 package MooX::Pression;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.003';
+our $VERSION   = '0.004';
 
 use Keyword::Declare;
 use B::Hooks::EndOfScope;
@@ -213,9 +213,9 @@ my $handle_signature = sub {
 			$type_params_stuff .= '},';
 		}
 	}
-
+	
 	# TODO: slurpy still needs thought!
-
+	
 	@signature_var_list = '$arg' if $seen_named;
 	$type_params_stuff .= ']';
 	
@@ -399,6 +399,23 @@ sub import {
 		sprintf('q[%s]->_with(%s);', $me, join q[,], map B::perlstring($_), split /\s*,\s*/, $roles);
 	}
 	
+	# `requires` keyword
+	#
+	keyword requires (Identifier|Block $name, '(', SignatureList $sig, ')') {
+		sprintf(
+			'q[%s]->_requires(%s);',
+			$me,
+			($name =~ /^\{/ ? "scalar(do $name)" : B::perlstring($name)),
+		);
+	}
+	keyword requires (Identifier|Block $name) {
+		sprintf(
+			'q[%s]->_requires(%s);',
+			$me,
+			($name =~ /^\{/ ? "scalar(do $name)" : B::perlstring($name)),
+		);
+	}
+	
 	# `has` keyword
 	#
 	keyword has ('+'? $plus, /[\$\@\%]/? $sigil, Identifier $name, '!'? $postfix) {
@@ -561,6 +578,10 @@ sub _with {
 	shift;
 	push @{ $OPTS{with}||=[] }, @_;
 }
+sub _requires {
+	shift;
+	push @{ $OPTS{requires}||=[] }, @_;
+}
 sub _coerce {
 	shift;
 	push @{ $OPTS{coerce}||=[] }, @_;
@@ -1039,7 +1060,32 @@ For enumerations, you can define them like this:
     has status ( enum => ['alive', 'dead', 'undead'] );
   }
 
-It is possible to add hints to the name as a shortcut for common
+MooX::Pression integrates support for L<MooX::Enumeration> (and
+L<MooseX::Enumeration>).
+
+  class Person {
+    ...;
+    has status (
+      enum    => ['alive', 'dead', 'undead'],
+      default => 'alive',
+      handles => 1,
+    );
+  }
+  
+  my $bob = MyApp->new_person;
+  if ( $bob->is_alive ) {
+    ...;
+  }
+
+C<< handles => 1 >> creates methods named C<is_alive>, C<is_dead>, and
+C<is_undead>, and C<< handles => 2 >> creates methods named
+C<status_is_alive>, C<status_is_dead>, and C<status_is_undead>.
+
+Checking C<< $bob->status eq 'alvie' >> is prone to typos, but
+C<< $bob->status_is_alvie >> will cause a runtime error because the
+method is not defined.
+
+It is possible to add hints to the attribute name as a shortcut for common
 specifications.
 
   class Person {
@@ -1241,6 +1287,27 @@ deal with C<< @_ >> in the body of the method. In the second, there
 is a signature, but it is a signature showing that the method expects
 no arguments (other than the invocant of course).
 
+=head3 require
+
+Indicates that a role requires classes to fulfil certain methods.
+
+  role Payable {
+    requires account;
+    requires deposit (Num $amount);
+  }
+  
+  class Employee {
+    extends Person;
+    with Payable;
+    has account;
+    method deposit (Num $amount) {
+      ...;
+    }
+  }
+
+Required methods have an optional signature; this is currently
+ignored but may be useful for self-documenting code.
+
 =head3 C<< before >>
 
   before marry {
@@ -1537,6 +1604,245 @@ L<Types::Common::String>, and L<Types::Common::Numeric>.
 The ability to choose a toolkit on a package-by-package basis is not
 currently supported. (Though it's implemented in MooX::Press.)
 
+The C<< handles => 1 >> and C<< handles => 2 >> features for enum
+attributes are not supported with Mouse.
+
+=head2 MooX::Pression vs Moops
+
+MooX::Pression has fewer dependencies than Moops, and crucially doesn't
+rely on L<Package::Keyword> and L<Devel::CallParser> which have... issues.
+MooX::Pression uses Damian Conway's excellent L<Keyword::Declare>
+(which in turn uses L<PPR>) to handle most parsing needs, so parsing should
+be more predictable.
+
+Here are a few key syntax and feature differences.
+
+=head3 Declaring a class
+
+Moops:
+
+  class Foo::Bar 1.0 extends Foo with Bar {
+    ...;
+  }
+
+MooX::Pression:
+
+  class Foo::Bar {
+    version 1.0;
+    extends Foo;
+    with Bar;
+  }
+
+Moops and MooX::Pression use different logic for determining whether a class
+name is "absolute" or "relative". In Moops, classes containing a "::" are seen
+as absolute class names; in MooX::Pression, only classes I<starting with> "::"
+are taken to be absolute; all others are given the prefix.
+
+Moops:
+
+  package MyApp {
+    use Moops;
+    class Foo {
+      class Bar {
+        class Baz {
+          # Nesting class blocks establishes a naming
+          # heirarchy so this is MyApp::Foo::Bar::Baz!
+        }
+      }
+    }
+  }
+
+MooX::Pression:
+
+  package MyApp {
+    use MooX::Pression;
+    class Foo {
+      class Bar {
+        class Baz {
+          # This is only MyApp::Baz, but nesting
+          # establishes an @ISA chain instead.
+        }
+      }
+    }
+  }
+
+=head3 How namespacing works
+
+Moops:
+
+  use feature 'say';
+  package MyApp {
+    use Moops;
+    use List::Util qw(uniq);
+    class Foo {
+      say __PACKAGE__;         # MyApp::Foo
+      say for uniq(1,2,1,3);   # ERROR!
+      sub foo { ... }          # MyApp::Foo::foo()
+    }
+  }
+
+MooX::Pression:
+
+  use feature 'say';
+  package MyApp {
+    use MooX::Pression;
+    use List::Util qw(uniq);
+    class Foo {
+      say __PACKAGE__;         # MyApp
+      say for uniq(1,2,1,3);   # this works fine
+      sub foo { ... }          # MyApp::foo()
+    }
+  }
+
+This is why you can't use C<sub> to define methods in MooX::Pression.
+You need to use the C<method> keyword. In MooX::Pression, all the code
+in the class definition block is still executing in the parent
+package's namespace!
+
+=head3 Multimethods
+
+Moops:
+
+  class Foo {
+    multi method foo (ArrayRef $x) {
+      say "Fizz";
+    }
+    multi method foo (HashRef $x) {
+      say "Buzz";
+    }
+  }
+  
+  Foo->foo( [] );  # Fizz
+  Foo->foo( {} );  # Buzz
+
+Multimethods are not currently implemented in MooX::Pression.
+The workaround would be something like this:
+
+  class Foo {
+    method foo_arrayref (ArrayRef $x) {
+      say "Fizz";
+    }
+    method foo_hashref (HashRef $x) {
+      say "Buzz";
+    }
+    method foo (ArrayRef|HashRef $x) {
+      is_ArrayRef($x)
+        ? $self->foo_arrayref($x)
+        : $self->foo_hashref($x)
+    }
+  }
+  
+  Foo->foo( [] );  # Fizz
+  Foo->foo( {} );  # Buzz
+
+=head3 Other crazy Kavorka features
+
+Kavorka allows you to mark certain parameters as read-only or aliases,
+allows you to specify multiple names for named parameters, allows you
+to rename the invocant, allows you to give methods and parameters
+attributes, allows you to specify a method's return type, etc, etc.
+
+MooX::Pression's C<method> keyword is unlikely to ever offer as many
+features as that. It is unlikely to offer many more features than it
+currently offers.
+
+If you need fine-grained control over how C<< @_ >> is handled, just
+don't use a signature and unpack C<< @_ >> inside your method body
+however you need to.
+
+=head3 Lexical accessors
+
+Moops automatically imported C<lexical_has> from L<Lexical::Accessor>
+into each class. MooX::Pression does not, but thanks to how namespacing
+works, it only needs to be imported once if you want to use it.
+
+  package MyApp {
+    use MooX::Pression;
+    use Lexical::Accessor;
+    
+    class Foo {
+      my $identifier = lexical_has identifier => (
+        is      => rw,
+        isa     => Int,
+        default => sub { 0 },
+      );
+      
+      method some_method () {
+        $self->$identifier( 123 );    # set identifier
+        ...;
+        return $self->$identifier;    # get identifier
+      }
+    }
+  }
+
+Lexical accessors give you true private object attributes.
+
+=head3 Factories
+
+MooX::Pression puts an emphasis on having a factory package for instantiating
+objects. Moops didn't have anything similar.
+
+=head3 C<augment> and C<override>
+
+These are L<Moose> method modifiers that are not implemented by L<Moo>.
+Moops allows you to use these in Moose and Mouse classes, but not Moo
+classes. MooX::Pression simply doesn't support them.
+
+=head3 Type Libraries
+
+Moops allowed you to declare multiple type libraries, define type
+constraints in each, and specify for each class and role which type
+libraries you want it to use.
+
+MooX::Pression automatically creates a single type library for all
+your classes and roles within a module to use, and automatically
+populates it with the types it thinks you might want.
+
+If you need to use other type constraints:
+
+  package MyApp {
+    use MooX::Pression;
+    # Just import types into the factory package!
+    use Types::Path::Tiny qw( Path );
+    
+    class DataSource {
+      has file => ( type => Path );
+      
+      method set_file ( Path $file ) {
+        $self->file( $file );
+      }
+    }
+  }
+  
+  my $ds = MyApp->new_datasource;
+  $ds->set_file('blah.txt');      # coerce Str to Path
+  print $ds->file->slurp_utf8;
+
+=head3 Constants
+
+Moops:
+
+  class Foo {
+    define PI = 3.2;
+  }
+
+MooX::Pression:
+
+  class Foo {
+    constant PI = 3.2;
+  }
+
+=head2 Future Directions
+
+I'd like to consider adding Package::Variant support if that isn't too
+tricky.
+
+Slurpy parameters for methods need to be integrated.
+
+Something like MooX::HandlesVia or Moose native traits would be good.
+MooX::HandlesVia doesn't work well for non-reference values though.
+MooX::Enumeration proves that it's possible to do!
+
 =head1 BUGS
 
 Please report any bugs to
